==> dde-session-shell_5.4.13.orig.tar.xz: dde-session-shell-5.4.13/translations/dde-session-shell_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programlar bilgisayarın kapanmasını önlüyor ve kapanmaya zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Programı kapatmak için İptal&apos;i tıklayın ve ardından programı kapatın.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programlar bilgisayarın yeniden başlatılmasını engelliyor ve yeniden başlatmayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programlar bilgisayarın askıya alınmasını önlüyor ve askıya almayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programlar bilgisayarın hazırda bekletme kipine geçmesini engelliyor ve hazırda bekletme kipini zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programlar, bilgisayarın oturumu kapatmasını engelliyor ve oturumu kapatmak zorla veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Kapatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
        <source>Are you sure you want to log out?</source>
        <translation>Oturumu kapatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
        <source>Switch user</source>
        <translation>Kullanıcı değiştir</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
        <source>Switch system</source>
        <translation>Sistem değiştir</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
        <source>Wrong Password</source>
        <translation>Yanlış Parola</translation>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
        <source>The account or password is not correct. Please enter again.</source>
        <translation>Hesap veya parola doğru değil. Lütfen tekrar girin.</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="405"/>
        <source>Lock Screen</source>
        <translation>Ekranı Kilitle</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="409"/>
        <source>Failed to lock screen</source>
        <translation>Ekran kilitlenemedi</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="291"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Parmak izi doğrulama zaman aşımına uğradı, lütfen parolanızı elle girin</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="309"/>
        <source>Failed to match fingerprint</source>
        <translation>Parmak izi eşleştirilemedi</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="339"/>
        <source>Wrong Password</source>
        <translation>Yanlış Parola</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="133"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Yukarıdaki kullanıcılar oturum açmış durumda ve kapatma nedeniyle veriler kaybedilecek, kapatmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="137"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Yukarıdaki kullanıcıların oturumu açık ve yeniden başlatılınca veriler kaybolacak, yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="172"/>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="178"/>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="184"/>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="202"/>
        <source>Switch user</source>
        <translation>Kullanıcı değiştir</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="210"/>
        <source>Switch system</source>
        <translation>Sistem değiştir</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>Sistem izleyiciyi başlat</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
        <source>Account</source>
        <translation>Hesap</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
        <source>Please enter the account</source>
        <translation>Lütfen hesabı girin</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
        <source>Please enter the password</source>
        <translation>Lütfen parolayı girin</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform></translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="149"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programlar bilgisayarın kapanmasını önlüyor ve kapanmaya zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="150"/>
        <location filename="../src/widgets/warningcontent.cpp" line="155"/>
        <location filename="../src/widgets/warningcontent.cpp" line="159"/>
        <location filename="../src/widgets/warningcontent.cpp" line="163"/>
        <location filename="../src/widgets/warningcontent.cpp" line="167"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Programı kapatmak için İptal&apos;i tıklayın ve ardından programı kapatın.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="154"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programlar bilgisayarın yeniden başlatılmasını engelliyor ve yeniden başlatmayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="158"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programlar bilgisayarın askıya alınmasını önlüyor ve askıya almayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="162"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programlar bilgisayarın hazırda bekletme kipine geçmesini engelliyor ve hazırda bekletme kipini zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="166"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programlar, bilgisayarın oturumu kapatmasını engelliyor ve oturumu kapatmak zorla veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="182"/>
        <location filename="../src/widgets/warningcontent.cpp" line="235"/>
        <location filename="../src/widgets/warningcontent.cpp" line="267"/>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="185"/>
        <location filename="../src/widgets/warningcontent.cpp" line="237"/>
        <location filename="../src/widgets/warningcontent.cpp" line="270"/>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="188"/>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="190"/>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="192"/>
        <location filename="../src/widgets/warningcontent.cpp" line="273"/>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="268"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Kapatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="271"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="274"/>
        <source>Are you sure you want to log out?</source>
        <translation>Oturumu kapatmak istediğinize emin misiniz?</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.14.orig.tar.xz: dde-session-shell-5.5.14/translations/dde-session-shell_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Parmak izinizi doğrulayın</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Parmak izi kilitli, lütfen parola kullanın</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Parola</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfen 1 dakika sonra tekrar deneyin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Yanlış PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey gerekli</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>PIN&apos;inizi girin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika(s) sonra tekrar deneyin</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthenticationModule</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama başarılı</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform><numerusform>Doğrulama başarısız, %n şansınız kaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama başarısız oldu, sadece bir şans kaldı</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Parola</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Yanlış PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey gerekli</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Parmak izinizi doğrulayın</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>PIN&apos;inizi girin</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Parmak izi kilitli, lütfen parola kullanın</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfen 1 dakika sonra tekrar deneyin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform><numerusform>Lütfen %n dakika sonra tekrar deneyin</numerusform></translation>
    </message>
</context>
<context>
    <name>ContentWidget</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programlar bilgisayarın kapanmasını önlüyor ve kapanmaya zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Programı kapatmak için İptal&apos;i tıklayın ve ardından programı kapatın.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programlar bilgisayarın yeniden başlatılmasını engelliyor ve yeniden başlatmayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programlar bilgisayarın askıya alınmasını önlüyor ve askıya almayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programlar bilgisayarın hazırda bekletme kipine geçmesini engelliyor ve hazırda bekletme kipini zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programlar, bilgisayarın oturumu kapatmasını engelliyor ve oturumu kapatmak zorla veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Kapatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Oturumu kapatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Kullanıcı değiştir</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Sistem değiştir</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <source>Wrong account</source>
        <translation>Yanlış hesap</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Parola</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Ekranı Kilitle</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Ekran kilitlenemedi</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Parmak izi doğrulama zaman aşımına uğradı, lütfen parolanızı elle girin</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Parmak izi eşleştirilemedi</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Yukarıdaki kullanıcılar oturum açmış durumda ve kapatma nedeniyle veriler kaybedilecek, kapatmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Yukarıdaki kullanıcıların oturumu açık ve yeniden başlatılınca veriler kaybolacak, yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Kullanıcı değiştir</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Sistem değiştir</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Sistem izleyiciyi başlat</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <source>Account</source>
        <translation>Hesap</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Parmak izinizi doğrulayın</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Parolanızın süresi %n gün içinde dolacak, lütfen zamanında değiştirin </numerusform><numerusform>Parolanızın süresi %n gün içinde dolacak, lütfen zamanında değiştirin </numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Parolanın süresi doldu, lütfen değiştir</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programlar bilgisayarın kapanmasını önlüyor ve kapanmaya zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Programı kapatmak için İptal&apos;i tıklayın ve ardından programı kapatın.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programlar bilgisayarın yeniden başlatılmasını engelliyor ve yeniden başlatmayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programlar bilgisayarın askıya alınmasını önlüyor ve askıya almayı zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programlar bilgisayarın hazırda bekletme kipine geçmesini engelliyor ve hazırda bekletme kipini zorlamak veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programlar, bilgisayarın oturumu kapatmasını engelliyor ve oturumu kapatmak zorla veri kaybına neden olabilir.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Kapatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Yeniden başlatmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Oturumu kapatmak istediğinize emin misiniz?</translation>
    </message>
</context>
</TS>
